==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaSecurityAccessControllerNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaSecurityAccessControllerNative

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4f1bfcdefb897db soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$java__5fsecurity__5fAccessController__5fdoPrivileged$b73f7144bd49c7b7(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$java__5fsecurity__5fAccessController__5fgetInheritedAccessControlContext$3434aa44a0fb29d8(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$java__5fsecurity__5fAccessController__5fgetStackAccessControlContext$04ebf63268a84b1c(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$v$999ad1fbc79da22c(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaSecurityAccessControllerNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaSecurityAccessControllerNative

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4f1bfcdefb897db soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$java__5fsecurity__5fAccessController__5fdoPrivileged$b73f7144bd49c7b7(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$java__5fsecurity__5fAccessController__5fgetInheritedAccessControlContext$3434aa44a0fb29d8(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$java__5fsecurity__5fAccessController__5fgetStackAccessControlContext$04ebf63268a84b1c(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$method$v$999ad1fbc79da22c(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaSecurityAccessControllerNative_H_ */
